#include "main.h"
//-------------------------------------------------------------
static const char *TAG = "main";
//-------------------------------------------------------------
void app_main(void)
{
  gpio_reset_pin(CONFIG_BLINK_GPIO);
  gpio_set_direction(CONFIG_BLINK_GPIO, GPIO_MODE_OUTPUT);

  ESP_LOGI(TAG, "Initializing SPIFFS");

  esp_vfs_spiffs_conf_t conf = {
    .base_path = "/spiffs",
    .partition_label = NULL,
    .max_files = 5,
    .format_if_mount_failed = true
  };

  esp_err_t ret = esp_vfs_spiffs_register(&conf);

  if (ret != ESP_OK) {
      if (ret == ESP_FAIL) {
          ESP_LOGE(TAG, "Failed to mount or format filesystem");
      } else if (ret == ESP_ERR_NOT_FOUND) {
          ESP_LOGE(TAG, "Failed to find SPIFFS partition");
      } else {
          ESP_LOGE(TAG, "Failed to initialize SPIFFS (%s)", esp_err_to_name(ret));
      }
      return;
  }

  size_t total = 0, used = 0;
  ret = esp_spiffs_info(conf.partition_label, &total, &used);
  if (ret != ESP_OK) {
      ESP_LOGE(TAG, "Failed to get SPIFFS partition information (%s)", esp_err_to_name(ret));
  } else {
      ESP_LOGI(TAG, "Partition size: total: %d, used: %d", total, used);
  }

  /*
  FILE* f;
  ESP_LOGI(TAG, "Opening file");
  f = fopen("/spiffs/hello.txt", "w");
  if (f == NULL) {
      ESP_LOGE(TAG, "Failed to open file for writing");
      return;
  }

  fprintf(f, "Hello World!\n");
  fclose(f);
  ESP_LOGI(TAG, "File written");
  */

  ESP_LOGI(TAG, "Opening file");
  FILE* f = fopen("/spiffs/index.html", "rb");
  if (f == NULL) {
      ESP_LOGE(TAG, "Failed to open file for reading");
      return;
  }
  char str1[500];
  size_t n;
  n = fread(str1, 1, sizeof(str1), f);
  fclose(f);
  str1[n] = 0;

  ESP_LOGI(TAG, "Read from file:\r\n%s", str1);

  while (1) {
    vTaskDelay(1000 / portTICK_PERIOD_MS);
  }
}
